==> jc-1.4.0.tar.gz: gnu/xml/transform/DocumentFunction.h <==
// final class gnu.xml.transform.DocumentFunction

// class file dependencies
// @dep_class bec1dbcd2b4b76b3 gnu_xml_transform_DocumentFunction
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_transform_DocumentFunction_H_
#define _JC_gnu_xml_transform_DocumentFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_DocumentFunction$sub_refs	_jc_gnu_xml_transform_DocumentFunction$sub_refs;
typedef struct _jc_gnu_xml_transform_DocumentFunction$sub_nonrefs	_jc_gnu_xml_transform_DocumentFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_DocumentFunction$refs	_jc_gnu_xml_transform_DocumentFunction$refs;
typedef struct _jc_gnu_xml_transform_DocumentFunction$nonrefs	_jc_gnu_xml_transform_DocumentFunction$nonrefs;
typedef struct _jc_gnu_xml_transform_DocumentFunction$object	_jc_gnu_xml_transform_DocumentFunction$object;

typedef const struct _jc_gnu_xml_transform_DocumentFunction$vmethods	_jc_gnu_xml_transform_DocumentFunction$vmethods;
typedef const struct _jc_gnu_xml_transform_DocumentFunction$vtable	_jc_gnu_xml_transform_DocumentFunction$vtable;
typedef const struct _jc_gnu_xml_transform_DocumentFunction$vtype	_jc_gnu_xml_transform_DocumentFunction$vtype;

// Constructors
extern void _jc_gnu_xml_transform_DocumentFunction$method$_init$2017eae0625b8a59(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_transform_DocumentFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_gnu_xml_transform_DocumentFunction$method$document$5628b2ea0a85c993(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_DocumentFunction$method$evaluate$f399496e60bca5df(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_DocumentFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *, jint, jint);
extern void _jc_gnu_xml_transform_DocumentFunction$method$setArguments$09123773dfa6e512(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_DocumentFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_transform_DocumentFunction$method_info$document$5628b2ea0a85c993;
extern _jc_method _jc_gnu_xml_transform_DocumentFunction$method_info$evaluate$f399496e60bca5df;
extern _jc_method _jc_gnu_xml_transform_DocumentFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_transform_DocumentFunction$method_info$setArguments$09123773dfa6e512;

// Virtual methods structure
struct _jc_gnu_xml_transform_DocumentFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*document$5628b2ea0a85c993)(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_Object$object	*(*evaluate$f399496e60bca5df)(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *, jint, jint);
	void	(*setArguments$09123773dfa6e512)(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_xml_transform_DocumentFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_transform_DocumentFunction$vmethods	gnu_xml_transform_DocumentFunction;
};

// Vtype
struct _jc_gnu_xml_transform_DocumentFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_DocumentFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_DocumentFunction$sub_refs {
	struct _jc_gnu_xml_transform_Stylesheet$object	*stylesheet;
	struct _jc_object	*base;
	struct _jc_object	*args;
	struct _jc_object	*values;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_DocumentFunction$refs {
    _jc_gnu_xml_transform_DocumentFunction$sub_refs	gnu_xml_transform_DocumentFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_DocumentFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_DocumentFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_transform_DocumentFunction$sub_nonrefs	gnu_xml_transform_DocumentFunction;
};

// Object instance structure
struct _jc_gnu_xml_transform_DocumentFunction$object {
	_jc_gnu_xml_transform_DocumentFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_DocumentFunction$vtype	*vtype;
	_jc_gnu_xml_transform_DocumentFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_DocumentFunction$vtype _jc_gnu_xml_transform_DocumentFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_DocumentFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_DocumentFunction$class_object;

#endif	/* _JC_gnu_xml_transform_DocumentFunction_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/DocumentFunction.h <==
// final class gnu.xml.transform.DocumentFunction

// class file dependencies
// @dep_class bec1dbcd2b4b76b3 gnu_xml_transform_DocumentFunction
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_transform_DocumentFunction_H_
#define _JC_gnu_xml_transform_DocumentFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_DocumentFunction$sub_refs	_jc_gnu_xml_transform_DocumentFunction$sub_refs;
typedef struct _jc_gnu_xml_transform_DocumentFunction$sub_nonrefs	_jc_gnu_xml_transform_DocumentFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_DocumentFunction$refs	_jc_gnu_xml_transform_DocumentFunction$refs;
typedef struct _jc_gnu_xml_transform_DocumentFunction$nonrefs	_jc_gnu_xml_transform_DocumentFunction$nonrefs;
typedef struct _jc_gnu_xml_transform_DocumentFunction$object	_jc_gnu_xml_transform_DocumentFunction$object;

typedef const struct _jc_gnu_xml_transform_DocumentFunction$vmethods	_jc_gnu_xml_transform_DocumentFunction$vmethods;
typedef const struct _jc_gnu_xml_transform_DocumentFunction$vtable	_jc_gnu_xml_transform_DocumentFunction$vtable;
typedef const struct _jc_gnu_xml_transform_DocumentFunction$vtype	_jc_gnu_xml_transform_DocumentFunction$vtype;

// Constructors
extern void _jc_gnu_xml_transform_DocumentFunction$method$_init$2017eae0625b8a59(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_gnu_xml_transform_Stylesheet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_transform_DocumentFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_transform_DocumentFunction$method$document$5628b2ea0a85c993(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_DocumentFunction$method$evaluate$f399496e60bca5df(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_DocumentFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_DocumentFunction$method$setArguments$09123773dfa6e512(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_DocumentFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_transform_DocumentFunction$method_info$document$5628b2ea0a85c993;
extern _jc_method _jc_gnu_xml_transform_DocumentFunction$method_info$evaluate$f399496e60bca5df;
extern _jc_method _jc_gnu_xml_transform_DocumentFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_transform_DocumentFunction$method_info$setArguments$09123773dfa6e512;

// Virtual methods structure
struct _jc_gnu_xml_transform_DocumentFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*document$5628b2ea0a85c993)(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$f399496e60bca5df)(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	void	(*setArguments$09123773dfa6e512)(_jc_env *, struct _jc_gnu_xml_transform_DocumentFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_DocumentFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_transform_DocumentFunction$vmethods	gnu_xml_transform_DocumentFunction;
};

// Vtype
struct _jc_gnu_xml_transform_DocumentFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_DocumentFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_DocumentFunction$sub_refs {
	struct _jc_gnu_xml_transform_Stylesheet$object	*stylesheet;
	struct _jc_object	*base;
	struct _jc_object	*args;
	struct _jc_object	*values;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_DocumentFunction$refs {
    _jc_gnu_xml_transform_DocumentFunction$sub_refs	gnu_xml_transform_DocumentFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_DocumentFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_DocumentFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_transform_DocumentFunction$sub_nonrefs	gnu_xml_transform_DocumentFunction;
};

// Object instance structure
struct _jc_gnu_xml_transform_DocumentFunction$object {
	_jc_gnu_xml_transform_DocumentFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_DocumentFunction$vtype	*vtype;
	_jc_gnu_xml_transform_DocumentFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_DocumentFunction$vtype _jc_gnu_xml_transform_DocumentFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_DocumentFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_DocumentFunction$class_object;

#endif	/* _JC_gnu_xml_transform_DocumentFunction_H_ */
